@@ -264,29 +264,6 @@ CAMLprim value ocaml_vorbis_encode_float(value vdsp, value vogg, value data, val
   CAMLreturn(Val_unit);
 }
 
-/*
-CAMLprim value ocaml_vorbis_eos(value vdsp, value vogg)
-{
-  CAMLparam2(vdsp, vogg);
-  encoder_t *enc = Encoder_val(vdsp);
-  ogg_stream_state *os = Stream_state_val(vogg);
-
-  caml_enter_blocking_section();
-  // Tell libvorbis that this is the end of the stream
-  vorbis_analysis_wrote(&enc->vd, 0);
-  while(vorbis_analysis_blockout(&enc->vd, &enc->vb) == 1)
-  {
-    vorbis_analysis(&enc->vb, NULL);
-    vorbis_bitrate_addblock(&enc->vb);
-    while(vorbis_bitrate_flushpacket(&enc->vd, &enc->op))
-      ogg_stream_packetin(os, &enc->op);
-  }
-  caml_leave_blocking_section();
-
-  CAMLreturn(Val_unit);
-}
-*/
-
 
 /***** Decoding *****/
 
